==> jc-1.4.0.tar.gz: java/util/Collections__24ReverseComparator.h <==
// final class java.util.Collections$ReverseComparator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 16e4449bbde9c097 java_util_Collections__24ReverseComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Collections__24ReverseComparator_H_
#define _JC_java_util_Collections__24ReverseComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_util_Collections__24ReverseComparator$sub_refs	_jc_java_util_Collections__24ReverseComparator$sub_refs;
typedef struct _jc_java_util_Collections__24ReverseComparator$sub_nonrefs	_jc_java_util_Collections__24ReverseComparator$sub_nonrefs;
typedef struct _jc_java_util_Collections__24ReverseComparator$refs	_jc_java_util_Collections__24ReverseComparator$refs;
typedef struct _jc_java_util_Collections__24ReverseComparator$nonrefs	_jc_java_util_Collections__24ReverseComparator$nonrefs;
typedef struct _jc_java_util_Collections__24ReverseComparator$object	_jc_java_util_Collections__24ReverseComparator$object;

typedef struct _jc_java_util_Collections__24ReverseComparator$fields_struct	_jc_java_util_Collections__24ReverseComparator$fields_struct;
typedef const struct _jc_java_util_Collections__24ReverseComparator$vmethods	_jc_java_util_Collections__24ReverseComparator$vmethods;
typedef const struct _jc_java_util_Collections__24ReverseComparator$vtable	_jc_java_util_Collections__24ReverseComparator$vtable;
typedef const struct _jc_java_util_Collections__24ReverseComparator$vtype	_jc_java_util_Collections__24ReverseComparator$vtype;

// Class fields structure
struct _jc_java_util_Collections__24ReverseComparator$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24ReverseComparator$fields_struct _jc_java_util_Collections__24ReverseComparator$class_fields;

// Constructors
extern void _jc_java_util_Collections__24ReverseComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_Collections__24ReverseComparator$object *);

// Virtual methods
extern jint _jc_java_util_Collections__24ReverseComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_java_util_Collections__24ReverseComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24ReverseComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_java_util_Collections__24ReverseComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_java_util_Collections__24ReverseComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_util_Collections__24ReverseComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24ReverseComparator$vmethods	java_util_Collections__24ReverseComparator;
};

// Vtype
struct _jc_java_util_Collections__24ReverseComparator$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24ReverseComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24ReverseComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24ReverseComparator$refs {
    _jc_java_util_Collections__24ReverseComparator$sub_refs	java_util_Collections__24ReverseComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24ReverseComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24ReverseComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24ReverseComparator$sub_nonrefs	java_util_Collections__24ReverseComparator;
};

// Object instance structure
struct _jc_java_util_Collections__24ReverseComparator$object {
	_jc_java_util_Collections__24ReverseComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24ReverseComparator$vtype	*vtype;
	_jc_java_util_Collections__24ReverseComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24ReverseComparator$vtype _jc_java_util_Collections__24ReverseComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24ReverseComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24ReverseComparator$class_object;

#endif	/* _JC_java_util_Collections__24ReverseComparator_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24ReverseComparator.h <==
// final class java.util.Collections$ReverseComparator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 16e4449bbde9c097 java_util_Collections__24ReverseComparator

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_Collections__24ReverseComparator_H_
#define _JC_java_util_Collections__24ReverseComparator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_java_util_Collections__24ReverseComparator$sub_refs	_jc_java_util_Collections__24ReverseComparator$sub_refs;
typedef struct _jc_java_util_Collections__24ReverseComparator$sub_nonrefs	_jc_java_util_Collections__24ReverseComparator$sub_nonrefs;
typedef struct _jc_java_util_Collections__24ReverseComparator$refs	_jc_java_util_Collections__24ReverseComparator$refs;
typedef struct _jc_java_util_Collections__24ReverseComparator$nonrefs	_jc_java_util_Collections__24ReverseComparator$nonrefs;
typedef struct _jc_java_util_Collections__24ReverseComparator$object	_jc_java_util_Collections__24ReverseComparator$object;

typedef struct _jc_java_util_Collections__24ReverseComparator$fields_struct	_jc_java_util_Collections__24ReverseComparator$fields_struct;
typedef const struct _jc_java_util_Collections__24ReverseComparator$vmethods	_jc_java_util_Collections__24ReverseComparator$vmethods;
typedef const struct _jc_java_util_Collections__24ReverseComparator$vtable	_jc_java_util_Collections__24ReverseComparator$vtable;
typedef const struct _jc_java_util_Collections__24ReverseComparator$vtype	_jc_java_util_Collections__24ReverseComparator$vtype;

// Class fields structure
struct _jc_java_util_Collections__24ReverseComparator$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24ReverseComparator$fields_struct _jc_java_util_Collections__24ReverseComparator$class_fields;

// Constructors
extern void _jc_java_util_Collections__24ReverseComparator$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_Collections__24ReverseComparator$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_util_Collections__24ReverseComparator$method$compare$ef65339aa5f9531b(_jc_env *, struct _jc_java_util_Collections__24ReverseComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24ReverseComparator$method_info$compare$ef65339aa5f9531b;

// Virtual methods structure
struct _jc_java_util_Collections__24ReverseComparator$vmethods {
	jint	(*compare$ef65339aa5f9531b)(_jc_env *, struct _jc_java_util_Collections__24ReverseComparator$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24ReverseComparator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24ReverseComparator$vmethods	java_util_Collections__24ReverseComparator;
};

// Vtype
struct _jc_java_util_Collections__24ReverseComparator$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24ReverseComparator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24ReverseComparator$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24ReverseComparator$refs {
    _jc_java_util_Collections__24ReverseComparator$sub_refs	java_util_Collections__24ReverseComparator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24ReverseComparator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24ReverseComparator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24ReverseComparator$sub_nonrefs	java_util_Collections__24ReverseComparator;
};

// Object instance structure
struct _jc_java_util_Collections__24ReverseComparator$object {
	_jc_java_util_Collections__24ReverseComparator$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24ReverseComparator$vtype	*vtype;
	_jc_java_util_Collections__24ReverseComparator$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24ReverseComparator$vtype _jc_java_util_Collections__24ReverseComparator$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24ReverseComparator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24ReverseComparator$class_object;

#endif	/* _JC_java_util_Collections__24ReverseComparator_H_ */
